Crate rooting_forms
source ·Re-exports
Modules
- Republished types for macro use.
Structs
Traits
- Provides methods for creating forms from a type. All types that can appear as or within such forms must implement this. This is automatically implemented for
FormWith<()>so if implementing yourself, focus on that trait. - An object representing a form (the state of the form).
- Like
Formbut allows passing in additional context, for custom elements that need it.FormWith<()>is generated by theFormderive macro.