Module css

Module css 

Constants

ATTR_LABEL
This should be used on all inputs, since <label> isn’t used.
CSS_CLASS_BIG_INPUT
Used for two-column inputs like text area. Exclusive with other rf_input_ classes.
CSS_CLASS_BUTTON_ICON
CSS_CLASS_BUTTON_ICON_ADD
CSS_CLASS_BUTTON_ICON_DELETE
CSS_CLASS_BUTTON_ICON_MOVE_DOWN
CSS_CLASS_BUTTON_ICON_MOVE_UP
CSS_CLASS_ERROR
Used for validation errors, appears before the input (also before the associated label, if there is one).
CSS_CLASS_HIDDEN
Used to hide disabled variants - hidden to keep user input in case they re-enable later.
CSS_CLASS_LABEL
Used for the text label before form fields.
CSS_CLASS_OPTION_ENABLE
Used by the checkbox for options. Exclusive with other rf_input_ classes.
CSS_CLASS_SMALL_INPUT
Used for single-column inputs (text entry, checkbox). Exclusive with other rf_input_ classes.
CSS_CLASS_SUBFORM
Used for nested struct/enum fields, namely within variants or options.
CSS_CLASS_TEXT
Text input (div plus contenteditable, get contents with text_contents)
CSS_CLASS_VEC
CSS_CLASS_VEC_ITEMS
CSS_CLASS_VEC_ITEM_HEADER

Functions

css_class_depth
err_el