Module impl_str
rooting_
forms
0.2.0
Module impl_
str
Module Items
Structs
In crate rooting_
forms
rooting_forms
Module
impl_
str
Structs

BigString
A minimal string wrapper that creates a textarea form input.
From
StrForm
State
A helper form type for rust types that implement
FromStr
.