Trait rooting_forms::Form

source ·
pub trait Form {
    // Required method
    fn new_form(field: &str, from: Option<&Self>) -> Box<dyn FormState<Self>>;
}
Provides methods for creating forms from a type. All types that can appear as or within such forms must implement this. This is automatically implemented for FormWith<()> so if implementing yourself, focus on that trait.

Required Methods

source

fn new_form(field: &str, from: Option<&Self>) -> Box<dyn FormState<Self>>

Generates a form state manager to produce form elements and parse the entered values.

  • field - is the field name, for accessibility using aria-label. <label> isn’t used sometime due to anonymous fields in tuples.

  • from - data used to populate the initial form, for example if creating a form to edit existing data.

Object Safety

This trait is not object safe.

Implementors

source

impl<T: FormWith<()>> Form for T