Constants
- ATTR_
LABEL - This should be used on all inputs, since
<label>isn’t used. - CSS_
CLASS_ BIG_ INPUT - Used for two-column inputs like text area. Exclusive with other
rf_input_classes. - CSS_
CLASS_ BUTTON_ ICON - CSS_
CLASS_ BUTTON_ ICON_ ADD - CSS_
CLASS_ BUTTON_ ICON_ DELETE - CSS_
CLASS_ BUTTON_ ICON_ MOVE_ DOWN - CSS_
CLASS_ BUTTON_ ICON_ MOVE_ UP - CSS_
CLASS_ ERROR - Used for validation errors, appears before the input (also before the associated label, if there is one).
- CSS_
CLASS_ HIDDEN - Used to hide disabled variants - hidden to keep user input in case they re-enable later.
- CSS_
CLASS_ LABEL - Used for the text label before form fields.
- CSS_
CLASS_ OPTION_ ENABLE - Used by the checkbox for options. Exclusive with other
rf_input_classes. - CSS_
CLASS_ SMALL_ INPUT - Used for single-column inputs (text entry, checkbox). Exclusive with other
rf_input_classes. - CSS_
CLASS_ SUBFORM - Used for nested struct/enum fields, namely within variants or options.
- CSS_
CLASS_ TEXT - Text input (div plus contenteditable, get contents with text_contents)
- CSS_
CLASS_ VEC - CSS_
CLASS_ VEC_ ITEMS - CSS_
CLASS_ VEC_ ITEM_ HEADER