This should be used on all inputs, since <label> isn’t used.
Used for two-column inputs like text area. Exclusive with other form_input_
classes.
Used for validation errors, appears before the input (also before the
associated label, if there is one).
Used to hide disabled variants - hidden to keep user input in case they
re-enable later.
Used for the text label before form fields.
Used by the checkbox for options. Exclusive with other form_input_ classes.
Used for single-column inputs (text entry, checkbox). Exclusive with other
form_input_ classes.
Used for nested struct/enum fields, namely within variants or options.