Module rooting_forms::impl_str
source · Structs
- A minimal string wrapper that creates a textarea form input.
- A helper form type for rust types that implement
FromStr. - A minimal string wrapper that creates a password form input.
FromStr.